@@ -110,6 +110,9 @@ INTERNALERROR_COSCONFIGURATION = 'InternalError.CosConfiguration'
 # Backup filename signature failed.
 INTERNALERROR_COSSIGNURL = 'InternalError.CosSignUrl'
 
+# Failed to create a process
+INTERNALERROR_CREATEFLOWERROR = 'InternalError.CreateFlowError'
+
 # No database data has changed.
 INTERNALERROR_DBROWSAFFECTEDERROR = 'InternalError.DBRowsAffectedError'
 
@@ -239,6 +242,9 @@ INVALIDPARAMETER_ILLEGALTIME = 'InvalidParameter.IllegalTime'
 # Failed to find the requested instance.
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
+# The API doesn’t support instances of this payment mode
+INVALIDPARAMETER_NOTSUPPORTEDPAYMODE = 'InvalidParameter.NotSupportedPayMode'
+
 # You have no permission to manipulate this API or resource.
 INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 
