@@ -41,6 +41,9 @@ FAILEDOPERATION_IMAGEARGINVALID = 'FailedOperation.ImageArgInvalid'
 # The user origin ID already exists.
 FAILEDOPERATION_ORIGINIDEXISTS = 'FailedOperation.OriginIdExists'
 
+# 
+FAILEDOPERATION_REQUESTTIMEDOUT = 'FailedOperation.RequestTimedOut'
+
 # The class has not ended.
 FAILEDOPERATION_ROOMNOTEND = 'FailedOperation.RoomNotEnd'
 
