@@ -109,7 +109,6 @@ class TrtcClient(AbstractClient):
 
     def DescribeMixTranscodingUsage(self, request):
         """This API is used to query your usage of TRTC’s On-Cloud MixTranscoding service.
-        Note: This API is not available for applications whose SDKAppID starts with `14`.
         - If the period queried is one day or shorter, the statistics returned are on a five-minute basis. If the period queried is longer than one day, the statistics returned are on a daily basis.
         - The period queried per request cannot be longer than 31 days.
         - If you query the statistics of the current day, the statistics returned may be inaccurate due to the delay in data collection.
@@ -138,7 +137,6 @@ class TrtcClient(AbstractClient):
 
     def DescribeRecordingUsage(self, request):
         """This API is used to query your TRTC recording usage.
-        Note: This API is not available for applications whose SDKAppID starts with `14`.
         - If the period queried is one day or shorter, the statistics returned are on a five-minute basis. If the period queried is longer than one day, the statistics returned are on a daily basis.
         - The period queried per request cannot be longer than 31 days.
         - If you query the statistics of the current day, the statistics returned may be inaccurate due to the delay in data collection.
@@ -167,7 +165,6 @@ class TrtcClient(AbstractClient):
 
     def DescribeRelayUsage(self, request):
         """This API is used to query your usage of TRTC’s relay to CDN service.
-        Note: This API is not available for applications whose SDKAppID starts with `14`.
         - If the period queried is one day or shorter, the statistics returned are on a five-minute basis. If the period queried is longer than one day, the statistics returned are on a daily basis.
         - The period queried per request cannot be longer than 31 days.
         - If you query the statistics of the current day, the statistics returned may be inaccurate due to the delay in data collection.
@@ -194,9 +191,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTrtcRoomUsage(self, request):
+        """This API is used to query usage data grouped by room.
+        - The queried period cannot exceed 24 hours. If the period spans two different days, the data returned may not be accurate due to a delay in data collection. You can make multiple calls to query the usage on different days.
+        - You can use this API to query your historical usage or to reconcile data, but we do not recommend you use it for crucial business logic.
+        - The rate limit of this API is one call every 15 seconds.
+
+        :param request: Request instance for DescribeTrtcRoomUsage.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcRoomUsageRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcRoomUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTrtcRoomUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTrtcRoomUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTrtcUsage(self, request):
         """This API is used to query your TRTC audio/video duration.
-        Note: This API is not available for applications whose SDKAppID starts with `14`.
         - If the period queried is one day or shorter, the statistics returned are on a five-minute basis. If the period queried is longer than one day, the statistics returned are on a daily basis.
         - The period queried per request cannot be longer than 31 days.
         - If you query the statistics of the current day, the statistics returned may be inaccurate due to the delay in data collection.
